#!/bin/bash -e

# For debug. If you need it, please comment in.
#set -x

LOG_DIR="/vol_data/log"
LOG_FILE="$LOG_DIR/temp.txt"
LEDS=( app led1 green )

log_temp() {
	local now cpu_temp soc_temp

	now=$(TZ=JST-9 date -Iseconds)
	cpu_temp=$(awk '{print $1 / 1000}' /sys/class/thermal/thermal_zone0/temp 2>/dev/null)
	soc_temp=$(awk '{print $1 / 1000}' /sys/class/thermal/thermal_zone1/temp 2>/dev/null)

	mkdir -p "$LOG_DIR"
	if ! [ -e "$LOG_FILE" ]; then
		echo "time,cpu temperature${soc_temp:+,soc temperature}" > "$LOG_FILE"
	fi
	echo "$now,$cpu_temp,$soc_temp" >> "$LOG_FILE"
}

blink() {
	local led

	for led in "${LEDS[@]}"; do
		led="/sys/class/leds/$led/brightness"
		[ -e "$led" ] && break
	done
	if ! [ -w "$led" ]; then
		echo "Could not find led file" >&2
		exit 1
	fi

	while true; do
		echo 0 > "$led"
		sleep 0.5
		echo 1 > "$led"
		sleep 0.5
	done
}

log_temp
blink
